==> haskell-http-date-0.0.11-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-DhumFg1EBNbKRCoMAnnc0S
key:                  http-date-0.0.11-DhumFg1EBNbKRCoMAnnc0S
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  5eaa1ce7c9712a10e6d1d126164400aa
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-DhumFg1EBNbKRCoMAnnc0S
depends:
    array-0.5.4.0 attoparsec-0.14.4-7GZjDb6SGiTJIjdzxAUMPr
    base-4.15.1.0 bytestring-0.10.12.1 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.11-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-HHh1IqxZLH354GrOdZ5LUP
key:                  http-date-0.0.11-HHh1IqxZLH354GrOdZ5LUP
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  b35a7eb3f6c2bdba092930cc2bef5ab9
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-HHh1IqxZLH354GrOdZ5LUP
depends:
    array-0.5.4.0 attoparsec-0.14.4-Kojlk2njjLp4GDvYR5lc9z
    base-4.15.1.0 bytestring-0.10.12.1 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
